"""hdappserver URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.11/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.conf.urls import url, include
    2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf.urls import url, include
from django.contrib import admin
from django.views.generic import TemplateView
from djangoldp.views import LDPViewSet
from django.conf import settings 
from .models import Member, Skill, Project, Client, Cell, Channel, Role
from .views import userinfocustom

urlpatterns = [
    url(r'^$', TemplateView.as_view(template_name="index.html"), name="index"),
    url(r'^accounts/', include('django.contrib.auth.urls')),
    url(r'^admin/', admin.site.urls),
    url(r'^channels/', LDPViewSet.urls(model=Channel, nested_field="members")),
    url(r'^cells/', LDPViewSet.urls(model=Cell)),
    url(r'^clients/', LDPViewSet.urls(model=Client)),
    url(r'^members/', LDPViewSet.urls(model=Member, nested_field="skills")),
    url(r'^projects/', LDPViewSet.urls(model=Project, nested_field="team")),
    url(r'^skills/', LDPViewSet.urls(model=Skill)),
    url(r'^openid/userinfo', userinfocustom),
    url(r'^openid/', include('oidc_provider.urls', namespace='oidc_provider')),
    url(r'^role/', LDPViewSet.urls(model=Role)),
    url(r'^users/',  LDPViewSet.urls(model=settings.AUTH_USER_MODEL)), 
]


